@@ -39,7 +39,7 @@ EWAPI const Efl_Class *efl_container_interface_get(void);
  *
  * @ingroup Efl_Container
  */
-EOAPI Eina_Iterator *efl_content_iterate(Eo *obj) EINA_WARN_UNUSED_RESULT;
+EOAPI Eina_Iterator *efl_content_iterate(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Returns the number of contained sub-objects.
