@@ -14,9 +14,9 @@ typedef Eo Efl_Pack_Layout;
 
 #endif
 /**
- * @brief Low-level APIs for object that can lay their children out.
+ * @brief Low-level APIs for objects that can lay their children out.
  *
- * Used for containers (box, grid).
+ * Used for containers like @ref Efl_Ui_Box and @ref Efl_Ui_Table.
  *
  * @ingroup Efl_Pack_Layout
  */
@@ -25,10 +25,9 @@ typedef Eo Efl_Pack_Layout;
 EWAPI const Efl_Class *efl_pack_layout_interface_get(void);
 
 /**
- * @brief Requests EFL to call the @ref efl_pack_layout_update method on this
- * object.
+ * @brief Requests EFL to recalculate the layout of this object.
  *
- * This @ref efl_pack_layout_update may be called asynchronously.
+ * Internal layout methods might be called asynchronously.
  * @param[in] obj The object.
  *
  * @ingroup Efl_Pack_Layout
@@ -40,9 +39,9 @@ EOAPI void efl_pack_layout_request(Eo *obj);
  * @brief Implementation of this container's layout algorithm.
  *
  * EFL will call this function whenever the contents of this container need to
- * be re-layed out on the canvas.
+ * be re-laid out on the canvas.
  *
- * This can be overriden to implement custom layout behaviours.
+ * This can be overridden to implement custom layout behaviors.
  * @param[in] obj The object.
  *
  * @ingroup Efl_Pack_Layout
@@ -50,4 +49,12 @@ EOAPI void efl_pack_layout_request(Eo *obj);
 EOAPI void efl_pack_layout_update(Eo *obj);
 #endif
 
+EWAPI extern const Efl_Event_Description _EFL_PACK_EVENT_LAYOUT_UPDATED;
+
+/** Sent after the layout was updated.
+ *
+ * @ingroup Efl_Pack_Layout
+ */
+#define EFL_PACK_EVENT_LAYOUT_UPDATED (&(_EFL_PACK_EVENT_LAYOUT_UPDATED))
+
 #endif
