@@ -419,14 +419,14 @@ EOAPI Efl_Access_Role efl_access_object_role_get(const Eo *obj);
  *
  * @ingroup Efl_Access_Object
  */
-EOAPI Eina_List *efl_access_object_access_children_get(const Eo *obj);
+EOAPI Eina_List *efl_access_object_access_children_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP;
 #endif
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
- * @brief Gets human-readable string indentifying object accessibility role.
+ * @brief Gets human-readable string identifying object accessibility role.
  *
  * @param[in] obj The object.
  *
@@ -441,16 +441,16 @@ EOAPI const char *efl_access_object_role_name_get(const Eo *obj);
 #ifdef EFL_BETA_API_SUPPORT
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
- * @brief Gets key-value pairs indentifying object extra attributes. Must be
+ * @brief Gets key-value pairs identifying object extra attributes. Must be
  * free by a user.
  *
  * @param[in] obj The object.
  *
- * @return List of object attributes, Must be freed by the user
+ * @return List of object attributes. Must be freed by the user
  *
  * @ingroup Efl_Access_Object
  */
-EOAPI Eina_List *efl_access_object_attributes_get(const Eo *obj);
+EOAPI Eina_List *efl_access_object_attributes_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP;
 #endif
 #endif /* EFL_BETA_API_SUPPORT */
 
@@ -484,10 +484,11 @@ EOAPI void efl_access_object_attributes_clear(Eo *obj);
 
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
- * @brief Sets reading information of an accessible object. If set as 0,
- * existing reading info will be deleted and by default all four reading
- * information types like name, role, state and description will be read on
- * object highlight
+ * @brief Reading information of an accessible object.
+ *
+ * If no reading information is set, 0 is returned which means all four reading
+ * information types will be read from object highlight. If set to 0, existing
+ * reading info will be deleted.
  *
  * @param[in] obj The object.
  * @param[in] reading_info Reading information types
@@ -499,9 +500,11 @@ EOAPI void efl_access_object_reading_info_type_set(Eo *obj, Efl_Access_Reading_I
 
 #ifdef EFL_ACCESS_OBJECT_PROTECTED
 /**
- * @brief Gets reading information types of an accessible object. if no reading
- * information is set, 0 is returned which means all four reading information
- * types will be read on object highlight
+ * @brief Reading information of an accessible object.
+ *
+ * If no reading information is set, 0 is returned which means all four reading
+ * information types will be read from object highlight. If set to 0, existing
+ * reading info will be deleted.
  *
  * @param[in] obj The object.
  *
@@ -714,7 +717,8 @@ EOAPI Eina_Bool efl_access_object_relationship_append(Eo *obj, Efl_Access_Relati
 /**
  * @brief Removes the relationship between two accessible objects.
  *
- * If relation_object is NULL function removes all relations of the given type.
+ * If relation_object is @c NULL function removes all relations of the given
+ * type.
  *
  * @param[in] obj The object.
  * @param[in] type Relation type
@@ -735,7 +739,7 @@ EOAPI void efl_access_object_relationships_clear(Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Get root object of accessible object hierarchy
+ * @brief Root object of accessible object hierarchy
  *
  * @return Root object
  *
