@@ -13,7 +13,14 @@ typedef Eo Efl_Ui_Calendar_Item;
 
 
 #endif
-/** EFL UI Calendar Item class
+#ifdef EFL_BETA_API_SUPPORT
+/**
+ * @brief Item in a @ref Efl_Ui_Calendar
+ *
+ * @ref efl_parent_set is the @ref Efl_Ui_Calendar object where this item is
+ * in.
+ *
+ * This object is usally internal and should not be instantiated or used.
  *
  * @ingroup Efl_Ui_Calendar_Item
  */
@@ -41,5 +48,6 @@ EOAPI void efl_ui_calendar_item_day_number_set(Eo *obj, int i);
  * @ingroup Efl_Ui_Calendar_Item
  */
 EOAPI int efl_ui_calendar_item_day_number_get(const Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
