@@ -13,6 +13,7 @@ typedef Eo Efl_Ui_Text_Factory_Fallback;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Internal factory for fallback cases.
  *
@@ -20,12 +21,11 @@ typedef Eo Efl_Ui_Text_Factory_Fallback;
  * emoticon - Strips off "file://" prefix for image items, to be used with the
  * image factory.
  *
- * @since 1.21
- *
  * @ingroup Efl_Ui_Text_Factory_Fallback
  */
 #define EFL_UI_TEXT_FACTORY_FALLBACK_CLASS efl_ui_text_factory_fallback_class_get()
 
 EWAPI const Efl_Class *efl_ui_text_factory_fallback_class_get(void);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
