@@ -46,6 +46,8 @@ typedef short Efl_Callback_Priority;
 
 #ifndef EFL_CALLBACK_PRIORITY_BEFORE
 /** Slightly more prioritized than default.
+ *
+ * @since 1.22
  *
  * @ingroup Efl
  */
@@ -54,6 +56,8 @@ typedef short Efl_Callback_Priority;
 
 #ifndef EFL_CALLBACK_PRIORITY_DEFAULT
 /** Default priority.
+ *
+ * @since 1.22
  *
  * @ingroup Efl
  */
@@ -62,38 +66,13 @@ typedef short Efl_Callback_Priority;
 
 #ifndef EFL_CALLBACK_PRIORITY_AFTER
 /** Slightly less prioritized than default.
- *
- * @ingroup Efl
- */
-#define EFL_CALLBACK_PRIORITY_AFTER 100
-#endif
-
-/**
- * @brief A parameter passed in event callbacks holding extra event parameters.
- *
- * This is the full event information passed to callbacks in C.
  *
  * @since 1.22
  *
  * @ingroup Efl
  */
-typedef struct _Efl_Event
-{
-  Efl_Object *object; /**< The object the callback was called on.
-                       *
-                       * @since 1.22 */
-  const Efl_Event_Description *desc; /**< The event description.
-                                      *
-                                      * @since 1.22 */
-  void *info; /**< Extra event information passed by the event caller. Must be
-               * cast to the event type declared in the EO file. Keep in mind
-               * that: 1) Objects are passed as a normal Eo*. Event subscribers
-               * can call functions on these objects. 2) Structs, built-in
-               * types and containers are passed as const pointers, with one
-               * level of indirection.
-               *
-               * @since 1.22 */
-} Efl_Event;
+#define EFL_CALLBACK_PRIORITY_AFTER 100
+#endif
 
 
 #endif
@@ -356,10 +335,10 @@ EOAPI Eina_Bool efl_invalidating_get(const Eo *obj);
  *
  * The object from the provider will then be returned. The base implementation
  * calls the provider_find function on the object parent, and returns its
- * result. If no parent is present NULL is returned. Each implementation has to
- * support this function by overriding it and returning itself if the interface
- * matches the parameter. If this is not done the class cannot be found up in
- * the object tree.
+ * result. If no parent is present @c NULL is returned. Each implementation has
+ * to support this function by overriding it and returning itself if the
+ * interface matches the parameter. If this is not done the class cannot be
+ * found up in the object tree.
  *
  * @param[in] obj The object.
  * @param[in] klass The class identifier to search for.
@@ -449,6 +428,7 @@ EOAPI Efl_Object *efl_finalize(Eo *obj);
  */
 EOAPI void efl_invalidate(Eo *obj);
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Find a child object with the given name and return it.
  *
@@ -467,6 +447,7 @@ EOAPI void efl_invalidate(Eo *obj);
  * @ingroup Efl_Object
  */
 EOAPI Efl_Object *efl_name_find(const Eo *obj, const char *search);
+#endif /* EFL_BETA_API_SUPPORT */
 
 /**
  * @brief Thaw events of object.
@@ -498,7 +479,7 @@ EOAPI void efl_event_thaw(Eo *obj);
 EOAPI void efl_event_freeze(Eo *obj);
 
 /**
- * @brief Gobally thaw events for ALL EFL OBJECTS.
+ * @brief Globally thaw events for ALL EFL OBJECTS.
  *
  * Allows event callbacks to be called for all EFL objects after they have been
  * disabled by @ref efl_event_global_freeze. The amount of thaws must match the
@@ -571,7 +552,7 @@ EOAPI void efl_event_callback_stop(Eo *obj);
  *
  * @ingroup Efl_Object
  */
-EOAPI void efl_event_callback_forwarder_priority_add(Eo *obj, const Efl_Event_Description *desc, Efl_Callback_Priority priority, Efl_Object *source) EINA_ARG_NONNULL(4);
+EOAPI void efl_event_callback_forwarder_priority_add(Eo *obj, const Efl_Event_Description *desc, Efl_Callback_Priority priority, Efl_Object *source);
 
 /**
  * @brief Remove an event callback forwarder for a specified event and object.
@@ -584,10 +565,10 @@ EOAPI void efl_event_callback_forwarder_priority_add(Eo *obj, const Efl_Event_De
  *
  * @ingroup Efl_Object
  */
-EOAPI void efl_event_callback_forwarder_del(Eo *obj, const Efl_Event_Description *desc, Efl_Object *new_obj) EINA_ARG_NONNULL(3);
+EOAPI void efl_event_callback_forwarder_del(Eo *obj, const Efl_Event_Description *desc, Efl_Object *new_obj);
 
 /**
- * @brief Get an iterator on all childrens
+ * @brief Get an iterator on all children.
  *
  * @param[in] obj The object.
  *
@@ -597,7 +578,7 @@ EOAPI void efl_event_callback_forwarder_del(Eo *obj, const Efl_Event_Description
  *
  * @ingroup Efl_Object
  */
-EOAPI Eina_Iterator *efl_children_iterator_new(Eo *obj) EINA_WARN_UNUSED_RESULT;
+EOAPI Eina_Iterator *efl_children_iterator_new(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
@@ -711,6 +692,39 @@ EOAPI void efl_allow_parent_unref_set(Eo *obj, Eina_Bool allow);
 EOAPI Eina_Bool efl_allow_parent_unref_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
+/**
+ * @brief Will register a manager of a specific class to be answered by
+ * @ref efl_provider_find.
+ *
+ * @param[in] obj The object.
+ * @param[in] klass The class provided by the registered provider.
+ * @param[in] provider The provider for the newly registered class that has to
+ * provide that said Efl.Class.
+ *
+ * @return @c true if successfully register, @c false otherwise.
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Object
+ */
+EOAPI Eina_Bool efl_provider_register(Eo *obj, const Efl_Class *klass, const Efl_Object *provider);
+
+/**
+ * @brief Will unregister a manager of a specific class that was previously
+ * registered and answered by @ref efl_provider_find.
+ *
+ * @param[in] obj The object.
+ * @param[in] klass The class provided by the provider to unregister for.
+ * @param[in] provider The provider for the registered class to unregister.
+ *
+ * @return @c true if successfully unregistered, @c false otherwise.
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Object
+ */
+EOAPI Eina_Bool efl_provider_unregister(Eo *obj, const Efl_Class *klass, const Efl_Object *provider);
+
 EWAPI extern const Efl_Event_Description _EFL_EVENT_DEL;
 
 /** Object is being deleted. See @ref efl_destructor.
@@ -742,6 +756,29 @@ EWAPI extern const Efl_Event_Description _EFL_EVENT_NOREF;
  */
 #define EFL_EVENT_NOREF (&(_EFL_EVENT_NOREF))
 
+EWAPI extern const Efl_Event_Description _EFL_EVENT_OWNERSHIP_UNIQUE;
+
+/** Object has lost a reference and only one is left. It has just one owner
+ * now. Triggered whenever the refcount goes from two to one.
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Object
+ */
+#define EFL_EVENT_OWNERSHIP_UNIQUE (&(_EFL_EVENT_OWNERSHIP_UNIQUE))
+
+EWAPI extern const Efl_Event_Description _EFL_EVENT_OWNERSHIP_SHARED;
+
+/** Object has acquired a second reference. It has multiple owners now.
+ * Triggered whenever increasing the refcount from one to two, it will not
+ * trigger by further increasing the refcount beyond two.
+ *
+ * @since 1.22
+ *
+ * @ingroup Efl_Object
+ */
+#define EFL_EVENT_OWNERSHIP_SHARED (&(_EFL_EVENT_OWNERSHIP_SHARED))
+
 EWAPI extern const Efl_Event_Description _EFL_EVENT_DESTRUCT;
 
 /** Object has been fully destroyed. It can not be used beyond this point. This
